@@ -31,6 +31,7 @@ public:
     QString faceId;
     QVariantMap colors;
     QVariantMap labels;
+    int updateRateLimit = 0;
     bool readOnly = true;
     bool showTitle = false;
 };
@@ -140,6 +141,9 @@ void FaceLoader::setColors(const QVariantMap &newColors)
     d->colors = newColors;
     if (d->controller) {
         d->controller->setSensorColors(d->colors);
+        // Ensure we emit a change signal for colors even if the controller thinks
+        // we shouldn't, to ensure all instances of the face are correctly updated.
+        Q_EMIT d->controller->sensorColorsChanged();
     }
     Q_EMIT colorsChanged();
 }
@@ -158,10 +162,34 @@ void FaceLoader::setLabels(const QVariantMap &newLabels)
     d->labels = newLabels;
     if (d->controller) {
         d->controller->setSensorLabels(d->labels);
+        // Ensure we emit a change signal for labels even if the controller thinks
+        // we shouldn't, to ensure all instances of the face are correctly updated.
+        Q_EMIT d->controller->sensorLabelsChanged();
     }
     Q_EMIT labelsChanged();
 }
 
+int FaceLoader::updateRateLimit() const
+{
+    return d->updateRateLimit;
+}
+
+void FaceLoader::setUpdateRateLimit(int newLimit)
+{
+    if (newLimit == d->updateRateLimit) {
+        return;
+    }
+
+    d->updateRateLimit = newLimit;
+    if (d->controller) {
+        d->controller->setUpdateRateLimit(d->updateRateLimit);
+        // Ensure we emit a change signal for the limit even if the controller thinks
+        // we shouldn't, to ensure all instances of the face are correctly updated.
+        Q_EMIT d->controller->updateRateLimitChanged();
+    }
+    Q_EMIT updateRateLimitChanged();
+}
+
 bool FaceLoader::readOnly() const
 {
     return d->readOnly;
@@ -214,6 +242,7 @@ void FaceLoader::Private::setupController()
     controller->setSensorLabels(labels);
     controller->setShowTitle(showTitle);
     controller->setFaceId(faceId);
+    controller->setUpdateRateLimit(updateRateLimit);
 
     Q_EMIT q->controllerChanged();
 }
