@@ -238,6 +238,11 @@ public:
     QAbstractItemModel *availableFacesModel();
     QAbstractItemModel *availablePresetsModel();
 
+    /**
+     * Load the configuration from a given config group
+     */
+    void loadConfig(KConfigGroup &config);
+
     /**
      * Reload the configuration.
      */
